LogLevel enum
Log levels for controlling the verbosity of logging output.
Values
- trace → const LogLevel
-
Trace level for very detailed logs, typically used for debugging.
- debug → const LogLevel
-
Debug level for general debugging information.
- info → const LogLevel
-
Info level for informational messages that highlight the progress of the application.
- warning → const LogLevel
-
Warning level for potentially harmful situations or important events that are not errors.
- error → const LogLevel
-
Error level for error events that might still allow the application to continue running.
- fatal → const LogLevel
-
Fatal level for very severe error events that will presumably lead the application to abort.
- off → const LogLevel
-
Off level to disable all logging.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited